/////////////////////////////////////////////////////////////////////
// Code/helloworld.cpp
// One of the EDGELIB tutorial samples for iPhone
//
// Copyright (c) 2008 Elements Interactive Mobile B.V.
// http://www.edgelib.com
//
// Show "hello world" on the screen and exit by tapping the screen
/////////////////////////////////////////////////////////////////////

/////////////////////////////////////////////////////////////////////
// Include and link the library                                    //
/////////////////////////////////////////////////////////////////////

#define EGL_USEGL

//Include EDGELIB
#include "edgemain.h"

#if defined(EGL_USEGL)
#if defined(EGL_USEGLES)
#include "GLES\\gl.h"
#include "GLES\\egl.h"
#elif defined(DEVICE_IPHONE)
#include <OpenGLES/ES1/gl.h>
#else
#include "GL\\gl.h"
#endif
#if defined(DEVICE_WIN32)
#if defined(EGL_PC)
#pragma comment(lib, "plugingl.lib")
#else
#if defined(DEVICE_DESKTOP)
#if defined(EGL_POWERVR)
#pragma comment(lib, "pluginpowervr.lib")
#elif defined(EGL_RASTEROID)
#pragma comment(lib, "pluginrasteroid.lib")
#endif
#else
#pragma comment(lib, "plugin1-0.lib")
#endif
#endif
#if defined(EGL_PC)
#pragma comment(lib, "opengl32.lib")
#elif defined(EGL_POWERVR)
#pragma comment(lib, "libgles_cl.lib")
#elif defined(EGL_NVIDIA)
#pragma comment(lib, "libgles_cm.lib")
#elif defined(EGL_RASTEROID)
#pragma comment(lib, "libEGL.lib")
#pragma comment(lib, "libGLES_CM_NoE.lib")
#endif
#endif
#endif

/////////////////////////////////////////////////////////////////////
// Class definition                                                //
/////////////////////////////////////////////////////////////////////

//The main class
class ClassMain : public ClassEdge
{
	public:
		ClassMain(void);
		~ClassMain(void);
	
		ERESULT OnDisplayConfig(EDISPLAYCONFIG *config);
		ERESULT OnDisplayInit(ENATIVETYPE instance,ClassEDisplay *display);
		ERESULT OnNextFrame(ClassEDisplay *display, unsigned long timedelta);
		void OnStylusDown(POINT pnt);
	
		E2DSurfaceRGBA m_FontSurf;
};


/////////////////////////////////////////////////////////////////////
// ClassMain: public                                               //
/////////////////////////////////////////////////////////////////////

//ClassMain: constructor
ClassMain::ClassMain(void)
{
}

//ClassMain: destructor
ClassMain::~ClassMain(void)
{
}

ERESULT
ClassMain::OnDisplayConfig(EDISPLAYCONFIG *config)
{
	// Configure display.
	config->videotype = EDSP_TRUE32_INV;
	config->emulvideotype = EDSP_TRUE32_INV;
	config->orientation = DOR_PORTRAIT;

	Log("ClassMain::OnDisplayConfig() - OK");
	return (E_OK);
} // End ClassMain::OnDisplayConfig().

ERESULT
ClassMain::OnDisplayInit(ENATIVETYPE instance,ClassEDisplay *display)
{
	display->Perspective2D(320, 480, false);
	display->SetShading(E3D_TEXTURE);
	
	long lResult;
	lResult = ecd.dsp->CreateSurface(&m_FontSurf,"Fuente.png",EST_READONLYPATH); // Replace "Fuente.png" by "Fuente2.png".
	if(E_OK!=lResult)
	{
		return E_ERROR;
	}

	m_FontSurf.SetFontSheetLayout(1,-1);
	m_FontSurf.SetFontCharacterSet(" ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789[\\]^_`{|}~!\"#$%&'()*+,-./:;<=>?@");	
	m_FontSurf.BuildFont(true);
	m_FontSurf.SetFontPadding(5);

	ecd.dsp->UploadTexture(&m_FontSurf,false);
	
	return E_OK;
}

//Callback: Called every frame
ERESULT ClassMain::OnNextFrame(ClassEDisplay *display, unsigned long timedelta)
{
	glClearColorx(0, 0, 0, 65536);
	ecd.dsp->Clear(true, true);

	display->DrawFont(10,10,&m_FontSurf,"HELLO WORLD!");
	return(E_OK);
}

//Callback: Called when the user points the stylus down or clicks the left mouse button
void ClassMain::OnStylusDown(POINT pnt)
{
	Quit();
}


/////////////////////////////////////////////////////////////////////
// The program entry point                                         //
/////////////////////////////////////////////////////////////////////

ClassEdge *EdgeMain(EDGESTARTUP *data){ return(new ClassMain); }
